@@ -76,7 +76,7 @@ const char default_right[] = "HIAX";
 static const uint TIMERINTERVAL = 25; // msec
 static const uint ANIMATIONSTEPS = 20;
 
-extern "C" KDE_EXPORT KDecorationFactory* create_factory() {
+extern "C" TDE_EXPORT KDecorationFactory* create_factory() {
     return new polyester::polyesterFactory();
 }
 
